__package__ = 'dsocli.provider.secret.aws.ssm.v1'
from .main import get_default_spec
from .main import AwsSsmSecretProvider
